Singleton

Struct Singleton 

pub struct Singleton { /* private fields */ }
The Singleton is a Reentrant Synchronization Type that can only be held by a single thread.

Implementations

Source

impl Singleton

pub fn new() -> Option<Self>

Take ownership of the Singleton, blocking until it becomes available. If the current thread already owns the Singleton, this function will return None. Otherwise, it will return an instance that, when dropped, will free the Singleton for another thread.